==> react_image_annotate_ns_workflow-7.0.4.tgz: package/HistorySidebarBox/index.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import HistoryIcon from "@mui/icons-material/History";
import UndoIcon from "@mui/icons-material/Undo";
import { Tooltip } from "@mui/material";
import { grey } from "@mui/material/colors";
import IconButton from "@mui/material/IconButton";
import List from "@mui/material/List";
import ListItem from "@mui/material/ListItem";
import ListItemSecondaryAction from "@mui/material/ListItemSecondaryAction";
import ListItemText from "@mui/material/ListItemText";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import { makeStyles } from "@mui/styles";
import isEqual from "lodash/isEqual";
import moment from "moment";
import React, { memo } from "react";
import SidebarBoxContainer from "../SidebarBoxContainer";
var theme = createTheme();
var useStyles = makeStyles(function (theme) {
  return {
    emptyText: {
      fontSize: 14,
      fontWeight: "bold",
      color: grey[500],
      textAlign: "center",
      padding: 20
    }
  };
});
var listItemTextStyle = {
  paddingLeft: 16
};
export var HistorySidebarBox = function HistorySidebarBox(_ref) {
  var history = _ref.history,
    onRestoreHistory = _ref.onRestoreHistory,
    delete_annotation = _ref.delete_annotation,
    setdelete_annotation = _ref.setdelete_annotation;
  var classes = useStyles();
  var undoAnnotation = function undoAnnotation() {
    var lastElement = window.undoArray[window.undoArray.length - 1];
    if (lastElement.includes("brush")) {
      var arrBrushData = _toConsumableArray(window.getBrushData() || []);
      var getlastIndexValue = arrBrushData[arrBrushData.length - 1];
      var setRedoBrushData = [].concat(_toConsumableArray(window.redoBrushData), [getlastIndexValue]);
      window.annotation_redo = [].concat(_toConsumableArray(window.annotation_redo), _toConsumableArray(setRedoBrushData));
      window.setBrushData(arrBrushData.slice(0, -1));
      var newArr = _toConsumableArray(window.undoArray);
      newArr.splice(window.undoArray.length - 1, 1);
      window.undoArray = newArr;
    }
    if (lastElement.includes("delete")) {
      var _arrBrushData = _toConsumableArray(window.getBrushData() || []);
      var getDeletedData = _toConsumableArray(window.deleteBrush.flat() || []);
      var getDeletedId = lastElement.split("~")[1];
      var notMatchDeleted = [];
      var getDeletedBrush = getDeletedData === null || getDeletedData === void 0 ? void 0 : getDeletedData.filter(function (item) {
        if (item.id === getDeletedId) {
          return item;
        } else {
          notMatchDeleted.push(item);
        }
      });
      window.setBrushData([].concat(_toConsumableArray(_arrBrushData), _toConsumableArray(getDeletedBrush)));
      var _newArr = _toConsumableArray(window.undoArray);
      _newArr.splice(window.undoArray.length - 1, 1);
      window.undoArray = _newArr;
      window.deleteBrush = notMatchDeleted;
    }
    if (lastElement.includes("deleteAllBrush")) {
      var _arrBrushData2 = _toConsumableArray(window.getBrushData() || []);
      var _getDeletedData = _toConsumableArray(window.deleteBrush.flat() || []);
      window.setBrushData([].concat(_toConsumableArray(_arrBrushData2), _toConsumableArray(_getDeletedData)));
      var _newArr2 = _toConsumableArray(window.undoArray);
      _newArr2.splice(window.undoArray.length - 1, 1);
      window.undoArray = _newArr2;
      window.deleteBrush = [];
    }
    if (!lastElement.includes("delete") && !lastElement.includes("brush")) {
      onRestoreHistory();
      var _newArr3 = _toConsumableArray(window.undoArray);
      _newArr3.splice(window.undoArray.length - 1, 1);
      window.undoArray = _newArr3;
    }
  };
  var handleUndoKeydown = function handleUndoKeydown() {
    var redoData = _toConsumableArray(window.annotation_redo);
    var getlastIndexValue = redoData[redoData.length - 1];
    if (getlastIndexValue.points) {
      var arrBrushData = [].concat(_toConsumableArray(window.getBrushData() || []), [getlastIndexValue]);
      window.setBrushData(arrBrushData);
      /** Remove annoatationRedo only brush or eraser lastIndex */
      var newArr = _toConsumableArray(window.annotation_redo);
      newArr.splice(window.annotation_redo.length - 1, 1);
      window.annotation_redo = newArr;
      /** End  */
      /** for undo Brush after Redo the */
      window.undoBrush();
    }
    if (getlastIndexValue.annotation) {
      window.hendleAnnotation_redo();
    }
  };
  var handleKeydown = function handleKeydown(key) {
    var _key$target2, _key$target2$parentNo;
    if (window.undoArray.length) {
      var _key$target, _key$target$parentNod;
      if (key.ctrlKey && key.code === "KeyZ") {
        undoAnnotation();
      } else if (key.target.id === "undo" || key.target.ariaLabel === "undo annotation" || _toConsumableArray((key === null || key === void 0 ? void 0 : (_key$target = key.target) === null || _key$target === void 0 ? void 0 : (_key$target$parentNod = _key$target.parentNode) === null || _key$target$parentNod === void 0 ? void 0 : _key$target$parentNod.classList) || []).indexOf("fa-undo") !== -1) {
        undoAnnotation();
      }
    } else {
      console.log("cant undo anymore");
    }
    if (key.ctrlKey && key.code === "KeyY") {
      handleUndoKeydown();
    } else if (key.target.id === "redo" || key.target.ariaLabel === "redo annotation" || _toConsumableArray((key === null || key === void 0 ? void 0 : (_key$target2 = key.target) === null || _key$target2 === void 0 ? void 0 : (_key$target2$parentNo = _key$target2.parentNode) === null || _key$target2$parentNo === void 0 ? void 0 : _key$target2$parentNo.classList) || []).indexOf("fa-redo") !== -1) {
      handleUndoKeydown();
    }
  };
  var clearWindow = function clearWindow() {
    window.removeEventListener("keydown", handleKeydown);
    window.removeEventListener("click", handleKeydown);
  };
  React.useEffect(function () {
    window.addEventListener("click", handleKeydown);
    window.addEventListener("keydown", handleKeydown);
    return function () {
      clearWindow();
    };
  }, []);
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SidebarBoxContainer, {
    title: "History",
    icon: /*#__PURE__*/React.createElement(HistoryIcon, {
      style: {
        color: grey[700]
      }
    }),
    expandedByDefault: true
  }, /*#__PURE__*/React.createElement(List, null, history.length === 0 && /*#__PURE__*/React.createElement("div", {
    className: classes.emptyText
  }, "No History Yet"), history.map(function (_ref2, i) {
    var name = _ref2.name,
      time = _ref2.time;
    return /*#__PURE__*/React.createElement(ListItem, {
      button: true,
      dense: true,
      key: i
    }, /*#__PURE__*/React.createElement(ListItemText, {
      style: listItemTextStyle,
      primary: name,
      secondary: moment(time).format("LT")
    }), i === 0 && /*#__PURE__*/React.createElement(ListItemSecondaryAction, {
      onClick: function onClick() {
        if (name === "Delete Region") {
          console.log(history);
        }
        onRestoreHistory();
      }
    }, /*#__PURE__*/React.createElement(Tooltip, {
      title: "Restore",
      placement: "right"
    }, /*#__PURE__*/React.createElement(IconButton, null, /*#__PURE__*/React.createElement(UndoIcon, null)))));
  }))));
};
export default memo(HistorySidebarBox, function (prevProps, nextProps) {
  return isEqual(prevProps.history.map(function (a) {
    return [a.name, a.time];
  }), nextProps.history.map(function (a) {
    return [a.name, a.time];
  }));
});

==> react_image_annotate_ns_workflow-7.1.4.tgz: package/HistorySidebarBox/index.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import HistoryIcon from "@mui/icons-material/History";
import UndoIcon from "@mui/icons-material/Undo";
import { Tooltip } from "@mui/material";
import { grey } from "@mui/material/colors";
import IconButton from "@mui/material/IconButton";
import List from "@mui/material/List";
import ListItem from "@mui/material/ListItem";
import ListItemSecondaryAction from "@mui/material/ListItemSecondaryAction";
import ListItemText from "@mui/material/ListItemText";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import { makeStyles } from "@mui/system";
import isEqual from "lodash/isEqual";
import moment from "moment";
import React, { memo } from "react";
import SidebarBoxContainer from "../SidebarBoxContainer";
var theme = createTheme();
var useStyles = makeStyles(function (theme) {
  return {
    emptyText: {
      fontSize: 14,
      fontWeight: "bold",
      color: grey[500],
      textAlign: "center",
      padding: 20
    }
  };
});
var listItemTextStyle = {
  paddingLeft: 16
};
export var HistorySidebarBox = function HistorySidebarBox(_ref) {
  var history = _ref.history,
    onRestoreHistory = _ref.onRestoreHistory,
    delete_annotation = _ref.delete_annotation,
    setdelete_annotation = _ref.setdelete_annotation;
  var classes = useStyles();
  var undoAnnotation = function undoAnnotation() {
    var lastElement = window.undoArray[window.undoArray.length - 1];
    if (lastElement.includes("brush")) {
      var arrBrushData = _toConsumableArray(window.getBrushData() || []);
      var getlastIndexValue = arrBrushData[arrBrushData.length - 1];
      var setRedoBrushData = [].concat(_toConsumableArray(window.redoBrushData), [getlastIndexValue]);
      window.annotation_redo = [].concat(_toConsumableArray(window.annotation_redo), _toConsumableArray(setRedoBrushData));
      window.setBrushData(arrBrushData.slice(0, -1));
      var newArr = _toConsumableArray(window.undoArray);
      newArr.splice(window.undoArray.length - 1, 1);
      window.undoArray = newArr;
    }
    if (lastElement.includes("delete")) {
      var _arrBrushData = _toConsumableArray(window.getBrushData() || []);
      var getDeletedData = _toConsumableArray(window.deleteBrush.flat() || []);
      var getDeletedId = lastElement.split("~")[1];
      var notMatchDeleted = [];
      var getDeletedBrush = getDeletedData === null || getDeletedData === void 0 ? void 0 : getDeletedData.filter(function (item) {
        if (item.id === getDeletedId) {
          return item;
        } else {
          notMatchDeleted.push(item);
        }
      });
      window.setBrushData([].concat(_toConsumableArray(_arrBrushData), _toConsumableArray(getDeletedBrush)));
      var _newArr = _toConsumableArray(window.undoArray);
      _newArr.splice(window.undoArray.length - 1, 1);
      window.undoArray = _newArr;
      window.deleteBrush = notMatchDeleted;
    }
    if (lastElement.includes("deleteAllBrush")) {
      var _arrBrushData2 = _toConsumableArray(window.getBrushData() || []);
      var _getDeletedData = _toConsumableArray(window.deleteBrush.flat() || []);
      window.setBrushData([].concat(_toConsumableArray(_arrBrushData2), _toConsumableArray(_getDeletedData)));
      var _newArr2 = _toConsumableArray(window.undoArray);
      _newArr2.splice(window.undoArray.length - 1, 1);
      window.undoArray = _newArr2;
      window.deleteBrush = [];
    }
    if (!lastElement.includes("delete") && !lastElement.includes("brush")) {
      onRestoreHistory();
      var _newArr3 = _toConsumableArray(window.undoArray);
      _newArr3.splice(window.undoArray.length - 1, 1);
      window.undoArray = _newArr3;
    }
  };
  var handleUndoKeydown = function handleUndoKeydown() {
    var redoData = _toConsumableArray(window.annotation_redo);
    var getlastIndexValue = redoData[redoData.length - 1];
    if (getlastIndexValue.points) {
      var arrBrushData = [].concat(_toConsumableArray(window.getBrushData() || []), [getlastIndexValue]);
      window.setBrushData(arrBrushData);
      /** Remove annoatationRedo only brush or eraser lastIndex */
      var newArr = _toConsumableArray(window.annotation_redo);
      newArr.splice(window.annotation_redo.length - 1, 1);
      window.annotation_redo = newArr;
      /** End  */
      /** for undo Brush after Redo the */
      window.undoBrush();
    }
    if (getlastIndexValue.annotation) {
      window.hendleAnnotation_redo();
    }
  };
  var handleKeydown = function handleKeydown(key) {
    var _key$target2, _key$target2$parentNo;
    if (window.undoArray.length) {
      var _key$target, _key$target$parentNod;
      if (key.ctrlKey && key.code === "KeyZ") {
        undoAnnotation();
      } else if (key.target.id === "undo" || key.target.ariaLabel === "undo annotation" || _toConsumableArray((key === null || key === void 0 ? void 0 : (_key$target = key.target) === null || _key$target === void 0 ? void 0 : (_key$target$parentNod = _key$target.parentNode) === null || _key$target$parentNod === void 0 ? void 0 : _key$target$parentNod.classList) || []).indexOf("fa-undo") !== -1) {
        undoAnnotation();
      }
    } else {
      console.log("cant undo anymore");
    }
    if (key.ctrlKey && key.code === "KeyY") {
      handleUndoKeydown();
    } else if (key.target.id === "redo" || key.target.ariaLabel === "redo annotation" || _toConsumableArray((key === null || key === void 0 ? void 0 : (_key$target2 = key.target) === null || _key$target2 === void 0 ? void 0 : (_key$target2$parentNo = _key$target2.parentNode) === null || _key$target2$parentNo === void 0 ? void 0 : _key$target2$parentNo.classList) || []).indexOf("fa-redo") !== -1) {
      handleUndoKeydown();
    }
  };
  var clearWindow = function clearWindow() {
    window.removeEventListener("keydown", handleKeydown);
    window.removeEventListener("click", handleKeydown);
  };
  React.useEffect(function () {
    window.addEventListener("click", handleKeydown);
    window.addEventListener("keydown", handleKeydown);
    return function () {
      clearWindow();
    };
  }, []);
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(SidebarBoxContainer, {
    title: "History",
    icon: /*#__PURE__*/React.createElement(HistoryIcon, {
      style: {
        color: grey[700]
      }
    }),
    expandedByDefault: true
  }, /*#__PURE__*/React.createElement(List, null, history.length === 0 && /*#__PURE__*/React.createElement("div", {
    className: classes.emptyText
  }, "No History Yet"), history.map(function (_ref2, i) {
    var name = _ref2.name,
      time = _ref2.time;
    return /*#__PURE__*/React.createElement(ListItem, {
      button: true,
      dense: true,
      key: i
    }, /*#__PURE__*/React.createElement(ListItemText, {
      style: listItemTextStyle,
      primary: name,
      secondary: moment(time).format("LT")
    }), i === 0 && /*#__PURE__*/React.createElement(ListItemSecondaryAction, {
      onClick: function onClick() {
        if (name === "Delete Region") {
          console.log(history);
        }
        onRestoreHistory();
      }
    }, /*#__PURE__*/React.createElement(Tooltip, {
      title: "Restore",
      placement: "right"
    }, /*#__PURE__*/React.createElement(IconButton, null, /*#__PURE__*/React.createElement(UndoIcon, null)))));
  }))));
};
export default memo(HistorySidebarBox, function (prevProps, nextProps) {
  return isEqual(prevProps.history.map(function (a) {
    return [a.name, a.time];
  }), nextProps.history.map(function (a) {
    return [a.name, a.time];
  }));
});
